@@ -58,6 +58,7 @@ from .model.pydantic import (
     dump_resolve_reference_action,
 )
 from .model.pydantic.types import DataTypeManager
+from .parser import LiteralType
 from .parser.base import Parser
 from .version import version as __version__
 
@@ -68,8 +69,6 @@ pysnooper.tracer.DISABLED = True
 DEFAULT_BASE_CLASS: str = 'pydantic.BaseModel'
 
 
-# ALL_MODEL: str = '#all#'
-
 SafeLoader.yaml_constructors[
     'tag:yaml.org,2002:timestamp'
 ] = SafeLoader.yaml_constructors['tag:yaml.org,2002:str']
@@ -139,6 +138,8 @@ class InputFileType(Enum):
     JsonSchema = 'jsonschema'
     Json = 'json'
     Yaml = 'yaml'
+    Dict = 'dict'
+    CSV = 'csv'
 
 
 class Error(Exception):
@@ -189,6 +190,8 @@ def generate(
     use_standard_collections: bool = False,
     use_schema_description: bool = False,
     reuse_model: bool = False,
+    encoding: str = 'utf-8',
+    enum_field_as_literal: Optional[LiteralType] = None,
 ) -> None:
     input_text: Optional[str] = None
     if input_file_type == InputFileType.Auto:
@@ -196,7 +199,7 @@ def generate(
             input_text_ = (
                 input_
                 if isinstance(input_, str)
-                else get_first_file(input_).read_text()
+                else get_first_file(input_).read_text(encoding=encoding)
             )
             input_file_type = (
                 InputFileType.OpenAPI
@@ -217,12 +220,36 @@ def generate(
 
         parser_class = JsonSchemaParser
 
-        if input_file_type in [InputFileType.Json, InputFileType.Yaml]:
+        if input_file_type in (
+            InputFileType.Json,
+            InputFileType.Yaml,
+            InputFileType.Dict,
+            InputFileType.CSV,
+        ):
             try:
                 if isinstance(input_, Path) and input_.is_dir():  # pragma: no cover
                     raise Error(f'Input must be a file for {input_file_type}')
-                input_text = input_ if isinstance(input_, str) else input_.read_text()
-                obj: Dict[Any, Any] = load_yaml(input_text)
+                obj: Dict[Any, Any]
+                if input_file_type == InputFileType.CSV:
+                    import csv
+
+                    def get_header_and_first_line(csv_file: IO[str]) -> Dict[str, Any]:
+                        csv_reader = csv.DictReader(csv_file)
+                        return dict(zip(csv_reader.fieldnames, next(csv_reader)))  # type: ignore
+
+                    if isinstance(input_, str):
+                        import io
+
+                        obj = get_header_and_first_line(io.StringIO(input_))
+                    else:
+                        with input_.open(encoding=encoding) as f:
+                            obj = get_header_and_first_line(f)
+                else:
+                    obj = load_yaml(
+                        input_
+                        if isinstance(input_, str)
+                        else input_.read_text(encoding=encoding)
+                    )
             except:
                 raise Error('Invalid file format')
             from genson import SchemaBuilder
@@ -253,6 +280,7 @@ def generate(
         else None,
         use_schema_description=use_schema_description,
         reuse_model=reuse_model,
+        enum_field_as_literal=enum_field_as_literal,
     )
 
     with chdir(output):
@@ -262,7 +290,9 @@ def generate(
             input_filename = '<stdin>'
         else:
             input_filename = input_.name
-    if isinstance(results, str):
+    if not results:
+        raise Error('Models not found in the input data')
+    elif isinstance(results, str):
 
         modules = {output: (results, input_filename)}
     else:
@@ -294,7 +324,7 @@ def generate(
         else:
             if not path.parent.exists():
                 path.parent.mkdir(parents=True)
-            file = path.open('wt')
+            file = path.open('wt', encoding=encoding)
 
         print(header.format(filename=filename), file=file)
         if body:
