@@ -1,5 +1,6 @@
 import enum as _enum
 import sys
+from collections import defaultdict
 from contextlib import contextmanager
 from pathlib import Path
 from typing import (
@@ -12,6 +13,7 @@ from typing import (
     Mapping,
     Optional,
     Set,
+    Tuple,
     Type,
     Union,
 )
@@ -28,6 +30,7 @@ from datamodel_code_generator import (
 from datamodel_code_generator.format import PythonVersion
 from datamodel_code_generator.model import DataModel, DataModelFieldBase
 from datamodel_code_generator.model.enum import Enum
+from datamodel_code_generator.parser import LiteralType
 
 from ..model import pydantic as pydantic_model
 from ..parser.base import Parser
@@ -143,7 +146,7 @@ class JsonSchemaObject(BaseModel):
     oneOf: List['JsonSchemaObject'] = []
     anyOf: List['JsonSchemaObject'] = []
     allOf: List['JsonSchemaObject'] = []
-    enum: List[str] = []
+    enum: List[Any] = []
     writeOnly: Optional[bool]
     properties: Optional[Dict[str, 'JsonSchemaObject']]
     required: List[str] = []
@@ -228,6 +231,8 @@ class JsonSchemaParser(Parser):
         base_path: Optional[Path] = None,
         use_schema_description: bool = False,
         reuse_model: bool = False,
+        encoding: str = 'utf-8',
+        enum_field_as_literal: Optional[LiteralType] = None,
     ):
         super().__init__(
             source=source,
@@ -253,12 +258,15 @@ class JsonSchemaParser(Parser):
             base_path=base_path,
             use_schema_description=use_schema_description,
             reuse_model=reuse_model,
+            encoding=encoding,
+            enum_field_as_literal=enum_field_as_literal,
         )
 
         self.remote_object_cache: Dict[str, Dict[str, Any]] = {}
         self.raw_obj: Dict[Any, Any] = {}
         self._root_id: Optional[str] = None
         self._root_id_base_path: Optional[str] = None
+        self.reserved_refs: DefaultDict[Tuple[str], Set[str]] = defaultdict(set)
 
     @property
     def root_id(self) -> Optional[str]:
@@ -278,6 +286,11 @@ class JsonSchemaParser(Parser):
     def root_id_base_path(self) -> Optional[str]:
         return self._root_id_base_path
 
+    def should_parse_enum_as_literal(self, obj: JsonSchemaObject) -> bool:
+        return self.enum_field_as_literal == LiteralType.All or (
+            self.enum_field_as_literal == LiteralType.One and len(obj.enum) == 1
+        )
+
     def get_data_type(self, obj: JsonSchemaObject) -> DataType:
         if obj.type is None:
             return self.data_type_manager.get_data_type(Types.any)
@@ -379,7 +392,7 @@ class JsonSchemaParser(Parser):
             else:
                 fields.extend(self.parse_object_fields(all_of_item, path))
         class_name = self.model_resolver.add(
-            path, name, class_name=True, unique=True
+            path, name, class_name=True, unique=True, loaded=True
         ).name
         self.set_additional_properties(class_name, obj)
         data_model_type = self.data_model_type(
@@ -486,8 +499,13 @@ class JsonSchemaParser(Parser):
                 else:
                     field_type = self.data_type_manager.get_data_type(Types.object)
             elif field.enum:
-                enum = self.parse_enum(field_name, field, [*path, field_name])
-                field_type = self.data_type.from_model_name(enum.name)
+                if self.should_parse_enum_as_literal(field):
+                    field_type = self.data_type_manager.data_type.create_literal(
+                        field.enum
+                    )
+                else:
+                    enum = self.parse_enum(field_name, field, [*path, field_name])
+                    field_type = self.data_type.from_model_name(enum.name)
             else:
                 field_type = self.get_data_type(field)
                 if self.field_constraints:
@@ -530,7 +548,12 @@ class JsonSchemaParser(Parser):
                 f'This argument will be removed in a future version'
             )
         class_name = self.model_resolver.add(
-            path, name, class_name=True, singular_name=singular_name, unique=True
+            path,
+            name,
+            class_name=True,
+            singular_name=singular_name,
+            unique=True,
+            loaded=True,
         ).name
         self.set_title(class_name, obj)
         self.set_additional_properties(class_name, additional_properties or obj)
@@ -589,7 +612,9 @@ class JsonSchemaParser(Parser):
                 )
             elif item.enum:
                 item_obj_data_types.append(
-                    self.data_type.from_model_name(
+                    self.data_type_manager.data_type.create_literal(item.enum)
+                    if self.should_parse_enum_as_literal(item)
+                    else self.data_type.from_model_name(
                         self.parse_enum(
                             name, item, field_path, singular_name=True
                         ).name,
@@ -626,7 +651,7 @@ class JsonSchemaParser(Parser):
         self, name: str, obj: JsonSchemaObject, path: List[str]
     ) -> DataModel:
         field = self.parse_array_fields(name, obj, [*path, name])
-        self.model_resolver.add(path, name)
+        self.model_resolver.add(path, name, loaded=True)
         data_model_root = self.data_model_root_type(
             name,
             [field],
@@ -657,6 +682,7 @@ class JsonSchemaParser(Parser):
             required = not obj.nullable and not (
                 obj.has_default and self.apply_default_values_for_required_fields
             )
+        self.model_resolver.add(path, name, loaded=True)
         data_model_root_type = self.data_model_root_type(
             name,
             [
@@ -695,9 +721,7 @@ class JsonSchemaParser(Parser):
         enum_fields: List[DataModelFieldBase] = []
 
         for i, enum_part in enumerate(obj.enum):
-            if obj.type == 'string' or (
-                isinstance(obj.type, list) and 'string' in obj.type
-            ):
+            if obj.type == 'string' or isinstance(enum_part, str):
                 default = f"'{enum_part}'"
                 field_name = enum_part
             else:
@@ -705,7 +729,12 @@ class JsonSchemaParser(Parser):
                 if obj.x_enum_varnames:
                     field_name = obj.x_enum_varnames[i]
                 else:
-                    field_name = f'{obj.type}_{enum_part}'
+                    prefix = (
+                        obj.type
+                        if isinstance(obj.type, str)
+                        else type(enum_part).__name__
+                    )
+                    field_name = f'{prefix}_{enum_part}'
             enum_fields.append(
                 self.data_model_field_type(
                     name=self.model_resolver.get_valid_name(field_name),
@@ -721,6 +750,7 @@ class JsonSchemaParser(Parser):
             singular_name=singular_name,
             singular_name_suffix='Enum',
             unique=True,
+            loaded=True,
         ).name
         enum = Enum(
             enum_name,
@@ -755,19 +785,25 @@ class JsonSchemaParser(Parser):
         return ref_body
 
     def _get_ref_body_from_remote(self, ref: str) -> Dict[Any, Any]:
-        cached_ref_body: Optional[Dict[str, Any]] = self.remote_object_cache.get(ref)
-        if cached_ref_body:
-            return cached_ref_body
         # Remote Reference – $ref: 'document.json' Uses the whole document located on the same server and in
         # the same location. TODO treat edge case
         if self.current_source_path and len(self.current_source_path.parts) > 1:
             full_path = self.base_path / self.current_source_path.parent / ref
         else:
             full_path = self.base_path / ref
+
+        ref_full_path = str(full_path)
+
+        cached_ref_body: Optional[Dict[str, Any]] = self.remote_object_cache.get(
+            ref_full_path
+        )
+        if cached_ref_body:
+            return cached_ref_body
+
         # yaml loader can parse json data.
-        with full_path.open() as f:
+        with full_path.open(encoding=self.encoding) as f:
             ref_body = load_yaml(f)
-        self.remote_object_cache[ref] = ref_body
+        self.remote_object_cache[ref_full_path] = ref_body
         return ref_body
 
     def parse_ref(self, obj: JsonSchemaObject, path: List[str]) -> None:
@@ -777,9 +813,9 @@ class JsonSchemaParser(Parser):
                 # https://swagger.io/docs/specification/using-ref/
                 if obj.ref_type == JSONReference.LOCAL:
                     # Local Reference – $ref: '#/definitions/myElement'
-                    pass
+                    self.reserved_refs[tuple(self.model_resolver.current_root)].add(obj.ref)  # type: ignore
                 elif self.model_resolver.is_after_load(obj.ref):
-                    pass
+                    self.reserved_refs[tuple(obj.ref.split('#')[0].split('/'))].add(obj.ref)  # type: ignore
                 else:
                     if obj.ref_type == JSONReference.REMOTE and self.root_id_base_path:
                         ref = f'{self.root_id_base_path}/{obj.ref}'
@@ -830,6 +866,8 @@ class JsonSchemaParser(Parser):
             self.parse_ref(item, path)
         for item in obj.allOf:
             self.parse_ref(item, path)
+        for item in obj.oneOf:
+            self.parse_ref(item, path)
         if obj.properties:
             for value in obj.properties.values():
                 self.parse_ref(value, path)
@@ -895,10 +933,11 @@ class JsonSchemaParser(Parser):
             self.model_resolver.after_load_files = {
                 s.path.as_posix() for s in self.iter_source
             }
+
         for source in self.iter_source:
+            path_parts = list(source.path.parts)
             if self.current_source_path is not None:
                 self.current_source_path = source.path
-            path_parts = list(source.path.parts)
             with self.model_resolver.current_root_context(path_parts):
                 self.raw_obj = load_yaml(source.text)
                 if self.class_name:
@@ -908,7 +947,45 @@ class JsonSchemaParser(Parser):
                     obj_name = self.raw_obj.get('title', 'Model')
                     if not self.model_resolver.validate_name(obj_name):
                         raise InvalidClassNameError(obj_name)
-                self._parse_file(self.raw_obj, obj_name, path_parts, path_parts)
+                self._parse_file(self.raw_obj, obj_name, [*path_parts], path_parts)
+
+        # resolve unparsed json pointer
+        for source in self.iter_source:
+            path_parts = list(source.path.parts)
+            reserved_refs = self.reserved_refs.get(tuple(path_parts))  # type: ignore
+            if not reserved_refs:
+                continue
+            if self.current_source_path is not None:
+                self.current_source_path = source.path
+
+            with self.model_resolver.current_root_context(path_parts):
+                for reserved_ref in sorted(reserved_refs):
+                    if self.model_resolver.add_ref(reserved_ref).loaded:
+                        continue
+                    file_path, model_path = reserved_ref.split('#', 1)
+                    valid_path_parts = [p for p in model_path.split('/') if p]
+                    if (
+                        len(valid_path_parts) == 1
+                        and self.model_resolver.add_ref(f'{file_path}#').loaded
+                    ):  # pragma: no cover
+                        continue
+                    # for root model
+                    self.raw_obj = load_yaml(source.text)
+                    self.parse_json_pointer(self.raw_obj, reserved_ref, path_parts)
+
+    def parse_json_pointer(
+        self, raw: Dict[str, Any], ref: str, path_parts: List[str]
+    ) -> None:
+        path = ref.split('#', 1)[-1]
+        if path[0] == '/':  # pragma: no cover
+            path = path[1:]
+        object_paths = path.split('/')
+        models = get_model_by_path(raw, object_paths)
+        model_name = object_paths[-1]
+
+        self.parse_raw_obj(
+            model_name, models, [*path_parts, f'#/{object_paths[0]}', *object_paths[1:]]
+        )
 
     def _parse_file(
         self,
