@@ -1,19 +1,18 @@
 import pytest
 
-from datamodel_code_generator.imports import (
+from datamodel_code_generator import PythonVersion
+from datamodel_code_generator.imports import Import
+from datamodel_code_generator.model.pydantic.imports import (
     IMPORT_CONDECIMAL,
     IMPORT_CONFLOAT,
     IMPORT_CONINT,
     IMPORT_CONSTR,
-    Import,
-)
-from datamodel_code_generator.model.pydantic.types import (
-    get_data_decimal_type,
-    get_data_float_type,
-    get_data_int_type,
-    get_data_str_type,
-    get_data_type,
+    IMPORT_NEGATIVE_FLOAT,
+    IMPORT_NEGATIVE_INT,
+    IMPORT_POSITIVE_FLOAT,
+    IMPORT_POSITIVE_INT,
 )
+from datamodel_code_generator.model.pydantic.types import DataTypeManager
 from datamodel_code_generator.types import DataType, Types
 
 
@@ -59,12 +58,20 @@ from datamodel_code_generator.types import DataType, Types
                 imports_=[IMPORT_CONINT],
             ),
         ),
-        (Types.integer, {'exclusiveMinimum': 0}, DataType(type='PositiveInt')),
-        (Types.integer, {'exclusiveMaximum': 0}, DataType(type='NegativeInt')),
+        (
+            Types.integer,
+            {'exclusiveMinimum': 0},
+            DataType(type='PositiveInt', imports_=[IMPORT_POSITIVE_INT]),
+        ),
+        (
+            Types.integer,
+            {'exclusiveMaximum': 0},
+            DataType(type='NegativeInt', imports_=[IMPORT_NEGATIVE_INT]),
+        ),
     ],
 )
 def test_get_data_int_type(types, params, data_type):
-    assert get_data_int_type(types, **params) == data_type
+    assert DataTypeManager().get_data_int_type(types, **params) == data_type
 
 
 @pytest.mark.parametrize(
@@ -121,12 +128,20 @@ def test_get_data_int_type(types, params, data_type):
                 imports_=[IMPORT_CONFLOAT],
             ),
         ),
-        (Types.float, {'exclusiveMinimum': 0}, DataType(type='PositiveFloat')),
-        (Types.float, {'exclusiveMaximum': 0}, DataType(type='NegativeFloat')),
+        (
+            Types.float,
+            {'exclusiveMinimum': 0},
+            DataType(type='PositiveFloat', imports_=[IMPORT_POSITIVE_FLOAT]),
+        ),
+        (
+            Types.float,
+            {'exclusiveMaximum': 0},
+            DataType(type='NegativeFloat', imports_=[IMPORT_NEGATIVE_FLOAT]),
+        ),
     ],
 )
 def test_get_data_float_type(types, params, data_type):
-    assert get_data_float_type(types, **params) == data_type
+    assert DataTypeManager().get_data_float_type(types, **params) == data_type
 
 
 @pytest.mark.parametrize(
@@ -192,7 +207,7 @@ def test_get_data_float_type(types, params, data_type):
     ],
 )
 def test_get_data_decimal_type(types, params, data_type):
-    assert get_data_decimal_type(types, **params) == data_type
+    assert DataTypeManager().get_data_decimal_type(types, **params) == data_type
 
 
 @pytest.mark.parametrize(
@@ -232,7 +247,7 @@ def test_get_data_decimal_type(types, params, data_type):
     ],
 )
 def test_get_data_str_type(types, params, data_type):
-    assert get_data_str_type(types, **params) == data_type
+    assert DataTypeManager().get_data_str_type(types, **params) == data_type
 
 
 @pytest.mark.parametrize(
@@ -252,7 +267,7 @@ def test_get_data_str_type(types, params, data_type):
     ],
 )
 def test_get_data_type(types, params, data_type):
-    assert get_data_type(types, **params) == data_type
+    assert DataTypeManager().get_data_type(types, **params) == data_type
 
 
 def test_data_type_type_hint():
